$VAR1 = {
         'en' => {
                  'firstname'           => 'Firstname',
                  'street'              => 'Street',
                  'email'               => 'Email Adress',
                  'save'                => 'Save',
                  'password'            => 'Password',
                  'wrongusername'       => 'Wrong Username',
                  'editMessage'         => 'Edit',
                  'caption'             => 'Caption',
                  'regmessage'          => 'You receive this email from Lindnerei.de ',
                  'category'            => 'Category',
                  'haveacount'          => 'You already have an Acount',
                  'sites'               => 'Sites',
                  'nomail'              => 'No Email Adress given.',
                  'name'                => 'Name',
                  'newMenu'             => 'Create new Menu',
                  'username'            => 'User',
                  'trash'               => 'Trash',
                  'preview'             => 'Preview',
                  'chars'               => 'Chars left:',
                  'newMessage'          => 'New Topic',
                  'userexits'           => 'This name is olready in use.<br/>',
                  'wrongpass'           => 'Wrong Password',
                  'mailsendet'          => '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
                  'edit'                => 'Bearbeiten',
                  'city'                => 'City',
                  'summary'             => 'Summary',
                  'insertText'          => 'Insert Text',
                  'postcode'            => 'Postcode',
                  'pass'                => 'Password',
                  'showwindow'          => 'Show Windows',
                  'familyname'          => 'Family Name',
                  'chooseFile'          => 'Choose Attachment',
                  'databases'           => 'Databases',
                  'phone'               => 'Phone Number',
                  'reply'               => 'Antworten',
                  'register'            => 'Register',
                  'mailsubject'         => 'Register',
                  'headline'            => 'Headline',
                  'realy'               => 'Realy',
                  'body'                => 'Body',
                  'newpass'             => 'New Password',
                  'retry'               => 'retry',
                  'upentry'             => 'Sort',
                  'downentry'           => 'Sort',
                  'edittreeviewentry'   => 'Edit',
                  'deletetreeviewentry' => 'Delete',
                  'addtreeviewentry'    => 'Add new entry',
                  'edittreeview'        => 'Edit',
                  'savetreeviewentry'   => 'Save',
                  'newTreeViewentry'    => 'New Entry',
                  'search'              => 'Search',
                  'edittree'            => 'Edit',
                  'Bookmarks'           => 'Bookmarks',
                  'answers'             => 'Answers',
                  'getpass'             => 'Lost Password',
                  'lostpass'            => 'Lost passwort',
                  'execSql'             => 'Exec Sql',
                  'newEntry'            => 'New Entry',
                  'showTableDetails'    => 'show Table Details',
                  'mysqldump'           => 'Mysql dump',
                  'deleteEntry'         => 'Delete Entry',
                  'editEntry'           => 'Edit Entry',
                  'openFile'            => 'Open File',
         },
         'de' => {
                  'firstname'           => 'Vorname',
                  'street'              => 'Strasse',
                  'email'               => 'Emailadresse',
                  'save'                => 'Speichern',
                  'password'            => 'Passwort',
                  'wrongusername'       => 'Sie haben keinen oder einen ungültigen usernamen eingegeben, bitte eingabe wiederhohlen.<br/>',
                  'editMessage'         => 'Bearbeiten',
                  'caption'             => '&#220;berschrift',
                  'regmessage'          => 'Sie ehalten diese Email weil versucht wurde sich auf lindnerei.de damit zu registrieren \\nWenn Sie diese Mail nicht angefordert haben bitte ich um entschuldigung.\\nAnsonsten lautet ihr \\n',
                  'category'            => 'Kategorie',
                  'haveacount'          => 'Sie haben bereits einen Acount',
                  'sites'               => 'Seiten',
                  'nomail'              => 'Sie haben keine email adresse angegeben.',
                  'name'                => 'Name',
                  'newMenu'             => 'Neues Menu erstellen',
                  'username'            => 'Benutzer',
                  'trash'               => 'M&#252;lleimer',
                  'preview'             => 'Vorschau',
                  'delete'              => 'L&#246;schen',
                  'chars'               => 'Zeichen &#252;brig:',
                  'newMessage'          => 'Neue Nachricht',
                  'sitemap'             => '&#252;bersicht',
                  'userexits'           => 'Dieser Benutzer exestiert bereits bitte einen anderen Namen ausw&#228;hlen<br/>',
                  'wrongpass'           => 'Falsches Passwort',
                  'mailsendet'          => '<div align="center">Sie haben eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
                  'edit'                => 'Bearbeiten',
                  'city'                => 'Stadt',
                  'summary'             => 'Zusammenfassung',
                  'insertText'          => 'Text einf&#252;gen',
                  'postcode'            => 'Postleitzahl',
                  'pass'                => 'Passwort',
                  'showwindow'          => 'Fenster anzeigen',
                  'familyname'          => 'Nachname',
                  'chooseFile'          => 'File ausw&#228;hlen',
                  'databases'           => 'Datenbanken',
                  'phone'               => 'Telefonnummer',
                  'reply'               => 'Antworten',
                  'answers'             => 'Antworten',
                  'register'            => 'Registrieren',
                  'mailsubject'         => 'Registrieren',
                  'headline'            => '&#220;berschrift',
                  'realy'               => 'Wirklich',
                  'body'                => 'Text',
                  'newpass'             => 'Neues Passwort',
                  'retry'               => 'Wiederholen',
                  'upentry'             => 'Sotieren',
                  'downentry'           => 'Sotieren',
                  'edittreeviewentry'   => 'Bearbeiten',
                  'deletetreeviewentry' => 'L&#246;sche',
                  'addtreeviewentry'    => 'Hinzuf&#252;gen',
                  'edittreeview'        => 'Bearbeiten',
                  'savetreeviewentry'   => 'Speichern',
                  'newtreeviewentry'    => 'Neuer Eintrag',
                  'search'              => 'Suchen',
                  'links'               => 'Links',
                  'edittree'            => 'Bearbeiten',
                  'Bookmarks'           => 'Links',
                  'getpass'             => 'Passwort vergessen',
                  'lostpass'            => 'Passwort vergessen',
                  'execSql'             => 'Exec Sql',
                  'newEntry'            => 'Neuer Eintrag',
                  'showTableDetails'    => 'Tabellen Details',
                  'mysqldump'           => 'Mysql dump',
                  'deleteEntry'         => 'Eintrag löschen',
                  'editEntry'           => 'Eintrag bearbeiten',
                  'openFile'            => 'Datei öffnen',
         },
};
$lang = $VAR1;
