my %parameter = (path => $settings->{cgi}{bin} . '/templates', style => $style, title => "", server => $settings->{serverName}, id => 'exploit', class => 'min',);
my $window = new HTML::Template::LZE::Window(\%parameter);
$window->set_closeable(0);
$window->set_moveable(0);
$window->set_resizeable(1);
print '<br/>';
print $window->windowHeader();
print "Permission denied", br();
my $rrds = CGI::remote_addr();
my $rqs  = CGI::query_string();
my $rgs  = CGI::referer();
$database->void("INSERT INTO exploit (referer,remote_addr,query_string) VALUES ('$rgs','$rrds' ,'$rqs');");
print $window->windowFooter();
