use lib qw(lib/);
use strict;
use CGI::LZE::Session;
use vars qw($session);
*session = \$CGI::LZE::Session::session;
$session = {query => "???Query.pl", Query => "./Query.pl"};
saveSession("./Query.pl");
undef $session;
use Test::More tests => 3;
my $t1 = $session->{query};
ok(not defined $t1);
loadSession("./Query.pl");
*session = \$CGI::LZE::Session::session;
$t1      = $session->{query};
my $t2 = $session->{Query};
ok($t1 eq "???Query.pl");
ok($t2 eq "./Query.pl");
system('rm ./Query.pl');
