[menuHeader]
<table align="center" border="0"  cellpadding="0" cellspacing="0" summary="layoutMenu" width="100%">
        <tr>
                <td >
<table align="center" border="0"  cellpadding="0" cellspacing="0" summary="layoutMenu" width="100%">
	<tr>
		<td class="underline">
		<table align="center" border="0" cellpadding="0" cellspacing="0" summary="layoutMenuLinks" >
			<tr>
[/menuHeader]
[links]
	<td width="10"><img src="/style/[style/]/tabwidget/mlU.png" alt="" title="[title/]" border="0" align="middle"/></td>
	<td class="under" align="left">[text/]</td>
	<td width="10" class="underR"></td>
[/links]

[currentLink]
	<td width="10"><img src="/style/[style/]/tabwidget/mlO.png" alt="" title="[title/]" border="0" align="middle" /></td>
	<td class="over" align="left" valign="middle">[text/]</td>
	<td width="10" class="overR"></td>
[/currentLink]
[javaScriptLink]
	<td width="10" id="dynamicTab1" style="display:none;"><img src="/style/[style/]/tabwidget/mlU.png" alt="" title="[title/]" border="0" align="middle" /></td>
	<td class="under" align="left" id="dynamicTab2" style="display:none;">[text/]</td>
	<td width="10" class="underR" id="dynamicTab3" style="display:none;"></td>
[/javaScriptLink]
[menuFooter]
	</tr>
		</table>
		</td>
	</tr>
</table>
[/menuFooter]
[bheader]
<table align="center" border="0" cellpadding="0" cellspacing="0" summary="layoutMenu"  width="100%">
<tr align="left" >
<td  style=" background-position:left;background-image:url('/style/[style/]/window/wlbg.png'); background-repeat:repeat-y;"></td>
<td align="center" valign="top" class="tabwidgetBody" width="100%" height="1000">
[/bheader]
[bfooter]
</td>
<td width="5" align="center" style=" background-position:left;background-image:url('/style/[style/]/window/wrbg.png');background-repeat:repeat-y;"></td>
</tr>
<tr align="left">
<td  width="5"><img src="/style/[style/]/window/wlubg.png" alt="" width="5" height="2" border="0"/></td>
<td style=" background-image:url('/style/[style/]/window/wdcubg.png'); background-repeat:repeat-x;"></td>
<td><img src="/style/[style/]/window/wrubg.png" alt="" width="5" height="2" border="0"/></td>
</tr>
</table></td></tr></table>
[bfooter/]
[action]
<table align ="left" border ="0" cellpadding ="0" cellspacing="0" summary="layoutMenuItem"><tr><td valign="bottom"><img onclick="location.href='[href/]'" src="/style/Crystal/buttons/[src/]" width="20" height="20" border="0" alt="" title="[title/]" style='font-size:14px;vertical-align:bottom;'/></td><td valign="middle"><a class="link" href="[href/]"  style='font-size:16px;vertical-align:bottom;' title="[title/]">[text/]</a></td></tr></table>
[/action]