use lib qw(lib/);
use strict;
use CGI::LZE::Settings;
use vars qw($settings);
*settings = \$CGI::LZE::Settings::settings;
$settings = {config => "???config.pl",};
saveSettings("./config.pl");
loadSettings("./config.pl");
my $t1 = $settings->{config};
$settings->{config} = "./config.pl";
saveSettings('./config.pl');
loadSettings('./config.pl');
my $t2 = $settings->{config};
use Test::More tests => 2;
ok($t1 eq "???config.pl");
ok($t2 eq "./config.pl");
system('rm ./config.pl');
1;
