[bodyHeader]<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
<title>[title/]</title>
<meta name="description" content="Dirk Lindner"/>
<meta name="author" content="Dirk Lindner"/>
<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"/>
<meta name="robots" content="index"/>
<meta http-equiv="cache-control" content="no-cache"/>
<meta http-equiv="expires" content="0">
 <link rel="alternate" type="application/rss+xml"  href="/news.rss"  title="News" /> 
<link href="/style/Crystal/lze.css" rel="stylesheet" type="text/css"/>
<link href="/style/Crystal/editor.css" rel="stylesheet" type="text/css"/>
<link href="/style/Crystal/tabwidget.css" rel="stylesheet" type="text/css"/>
<link href="/style/Crystal/window.css" rel="stylesheet" type="text/css"/>
<link href="/style/Crystal/pages.css" rel="stylesheet" type="text/css"/>
<link href="/style/Crystal/[size/]/html-menu-treeview/Crystal.css" rel="stylesheet" type="text/css"/>
<script language="JavaScript1.5"  type="text/javascript" src="/style/treeview.js"></script>
<script language="JavaScript1.5"  type="text/javascript" src="/javascript/content.js"></script>
<script language="JavaScript1.5"  type="text/javascript" src="/style/Crystal/preload.js"></script>
<script type="text/javascript">
 /* <![CDATA[ */
 style ="Crystal";
 right = [right/];
 htmlright = [htmlright/];
 /* ]]> */
 </script>
 </head>
 <body onunload="windowStatus()" onload="restoreStatus()"><table align="left"  border="0" cellpadding="0" cellspacing="0"  width="100%" summary="contentHeader"><tr><td valign="top"><table align="left" border="0" cellpadding="0" cellspacing="0"  width="100%" summary="contentHeader"><tr><td height="18"  valign="top">[login/]</td><td height="18"  align="right" valign="middle"><script src="/javascript/search.js" type="text/javascript" language="JavaScript"></script></td></tr></table></td></tr>
 <tr><td>
[bodyFooter]
 </td></tr>
 </table>
 </body></html>
